<?php
/**
 * MythClient implements required communication with the MythTV master server
 *
 * @version $Id: MythClient.php,v 1.1 2006/04/05 22:39:13 dbattams Exp $
 * @author Derek Battams <derek@battams.ca>
 * @package MRE
 * @copyright 2006 GPL v2
 */

/**#@+
 * Required include
 */
require_once(APP_ROOT . '/class/SysConf.php');
/**#@-*/

/**
 * A pseudo-MythTV client 
 *
 * A pseudo-MythTV client that allows invocation of required MythTV commands.
 * For now, it's a 'pseudo' client because all it actually does is call the
 * mythbackend binary with appropriate options, which for now is either
 * '--resched' to request a reschedule of events or '--version' to get the
 * running version number of MythTV to verifiy at startup.  This is all we need
 * from MythTV so I saw no point in writing a true client when these two 
 * commands do everything we need.  
 *
 * @package MRE
 */
class MythClient
{
   /**
    * @var string A prefix to the command, i.e. for ssh invocation, etc.
    */
   private $_cmdPrefix;

   /**
    * Class constructor
    */
   public function __construct()
   {
      $conf = SysConf::getInstance();
      $mythserv = $conf->getOpt('mythserv');
      if($mythserv != 'localhost')
         $this->setCmdPrefix("ssh mythtv@$mythserv ");
      else
         $this->setCmdPrefix('');
      return;
   }

   /**
    * Set the command prefix value
    *
    * @param string Value of the command prefix
    */
   protected function setCmdPrefix($str)
   {
      $this->_cmdPrefix = $str;
      return;
   }

   /**
    * Get the command prefix value
    *
    * @return string The command prefix value
    */
   protected function getCmdPrefix()
   {
      return $this->_cmdPrefix;
   }

   /**
    * Send a reschedule request to the MythTV backend
    *
    * @return bool Returns true on success or false otherwise
    */
   public function reschedule()
   {
      $cmd = $this->getCmdPrefix() . 'mythbackend --resched';
      exec($cmd, $out, $ret);
      if($ret)
      {
         $conf = SysConf::getInstance();
         if($conf->getOpt('verbose') >= SysConf::DEBUG)
         {
            echo "Output from MythTV reschedule request:\n";
            implode("\n", $out);
         }
         trigger_error("MythTV reschedule request failed!", E_USER_WARNING);
      }
      return $ret == 0;
   }

   /**
    * Get the version of MythTV the backend is running.
    *
    * @return string The MythTV version or '0' if an error occurred
    */
   public function getMythVersion()
   {
      $cmd = $this->getCmdPrefix() . 'mythbackend --version';
      exec($cmd, $out, $ret);
      if($ret)
      {
         $conf = SysConf::getInstance();
         if($conf->getOpt('verbose') >= SysConf::DEBUG)
         {
            echo "Output from MythTV reschedule request:\n";
            implode("\n", $out);
         }
         trigger_error("MythTV version request failed!", E_USER_WARNING);
         return '0';
      }
      foreach($out as $line)
         if(preg_match('/^Library API version: (.*)$/', $line, $matches))
            return $matches[1];
      return '0';
   }
}

?>
